@@ -14,8 +14,6 @@ use crate::num::*;
 use crate::scale::Scale;
 use crate::vector::{vec2, BoolVector2D, Vector2D};
 use crate::vector::{vec3, BoolVector3D, Vector3D};
-#[cfg(feature = "mint")]
-use mint;
 
 use core::cmp::{Eq, PartialEq};
 use core::fmt;
@@ -23,7 +21,14 @@ use core::hash::Hash;
 use core::iter::Sum;
 use core::marker::PhantomData;
 use core::ops::{Add, AddAssign, Div, DivAssign, Mul, MulAssign, Neg, Sub, SubAssign};
-use num_traits::{NumCast, Signed, Float};
+
+#[cfg(feature = "bytemuck")]
+use bytemuck::{Pod, Zeroable};
+#[cfg(feature = "malloc_size_of")]
+use malloc_size_of::{MallocSizeOf, MallocSizeOfOps};
+#[cfg(feature = "mint")]
+use mint;
+use num_traits::{Float, NumCast, Signed};
 #[cfg(feature = "serde")]
 use serde;
 
@@ -88,8 +93,7 @@ impl<'a, T, U> arbitrary::Arbitrary<'a> for Size2D<T, U>
 where
     T: arbitrary::Arbitrary<'a>,
 {
-    fn arbitrary(u: &mut arbitrary::Unstructured<'a>) -> arbitrary::Result<Self>
-    {
+    fn arbitrary(u: &mut arbitrary::Unstructured<'a>) -> arbitrary::Result<Self> {
         let (width, height) = arbitrary::Arbitrary::arbitrary(u)?;
         Ok(Size2D {
             width,
@@ -99,6 +103,19 @@ where
     }
 }
 
+#[cfg(feature = "bytemuck")]
+unsafe impl<T: Zeroable, U> Zeroable for Size2D<T, U> {}
+
+#[cfg(feature = "bytemuck")]
+unsafe impl<T: Pod, U: 'static> Pod for Size2D<T, U> {}
+
+#[cfg(feature = "malloc_size_of")]
+impl<T: MallocSizeOf, U> MallocSizeOf for Size2D<T, U> {
+    fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize {
+        self.width.size_of(ops) + self.height.size_of(ops)
+    }
+}
+
 impl<T, U> Eq for Size2D<T, U> where T: Eq {}
 
 impl<T, U> PartialEq for Size2D<T, U>
@@ -135,9 +152,9 @@ impl<T: Default, U> Default for Size2D<T, U> {
 }
 
 impl<T, U> Size2D<T, U> {
-    /// The same as [`Zero::zero()`] but available without importing trait.
+    /// The same as [`Zero::zero`] but available without importing trait.
     ///
-    /// [`Zero::zero()`]: ./num/trait.Zero.html#tymethod.zero
+    /// [`Zero::zero`]: crate::num::Zero::zero
     #[inline]
     pub fn zero() -> Self
     where
@@ -393,7 +410,7 @@ impl<T: NumCast + Copy, U> Size2D<T, U> {
 }
 
 impl<T: Float, U> Size2D<T, U> {
-    /// Returns true if all members are finite.
+    /// Returns `true` if all members are finite.
     #[inline]
     pub fn is_finite(self) -> bool {
         self.width.is_finite() && self.height.is_finite()
@@ -469,8 +486,8 @@ impl<T: PartialOrd, U> Size2D<T, U> {
         T: Zero,
     {
         let zero = T::zero();
-        // The condition is experessed this way so that we return true in
-        // the presence of NaN. 
+        // The condition is expressed this way so that we return true in
+        // the presence of NaN.
         !(self.width > zero && self.height > zero)
     }
 }
@@ -494,7 +511,7 @@ impl<T: PartialEq, U> Size2D<T, U> {
 }
 
 impl<T: Round, U> Round for Size2D<T, U> {
-    /// See [`Size2D::round()`](#method.round).
+    /// See [`Size2D::round`].
     #[inline]
     fn round(self) -> Self {
         self.round()
@@ -502,7 +519,7 @@ impl<T: Round, U> Round for Size2D<T, U> {
 }
 
 impl<T: Ceil, U> Ceil for Size2D<T, U> {
-    /// See [`Size2D::ceil()`](#method.ceil).
+    /// See [`Size2D::ceil`].
     #[inline]
     fn ceil(self) -> Self {
         self.ceil()
@@ -510,7 +527,7 @@ impl<T: Ceil, U> Ceil for Size2D<T, U> {
 }
 
 impl<T: Floor, U> Floor for Size2D<T, U> {
-    /// See [`Size2D::floor()`](#method.floor).
+    /// See [`Size2D::floor`].
     #[inline]
     fn floor(self) -> Self {
         self.floor()
@@ -550,13 +567,13 @@ impl<T: Copy + Add<T, Output = T>, U> Add<&Self> for Size2D<T, U> {
 }
 
 impl<T: Add<Output = T> + Zero, U> Sum for Size2D<T, U> {
-    fn sum<I: Iterator<Item=Self>>(iter: I) -> Self {
+    fn sum<I: Iterator<Item = Self>>(iter: I) -> Self {
         iter.fold(Self::zero(), Add::add)
     }
 }
 
 impl<'a, T: 'a + Add<Output = T> + Copy + Zero, U: 'a> Sum<&'a Self> for Size2D<T, U> {
-    fn sum<I: Iterator<Item=&'a Self>>(iter: I) -> Self {
+    fn sum<I: Iterator<Item = &'a Self>>(iter: I) -> Self {
         iter.fold(Self::zero(), Add::add)
     }
 }
@@ -670,12 +687,12 @@ impl<T, U> From<mint::Vector2<T>> for Size2D<T, U> {
     }
 }
 #[cfg(feature = "mint")]
-impl<T, U> Into<mint::Vector2<T>> for Size2D<T, U> {
+impl<T, U> From<Size2D<T, U>> for mint::Vector2<T> {
     #[inline]
-    fn into(self) -> mint::Vector2<T> {
+    fn from(s: Size2D<T, U>) -> Self {
         mint::Vector2 {
-            x: self.width,
-            y: self.height,
+            x: s.width,
+            y: s.height,
         }
     }
 }
@@ -687,10 +704,10 @@ impl<T, U> From<Vector2D<T, U>> for Size2D<T, U> {
     }
 }
 
-impl<T, U> Into<[T; 2]> for Size2D<T, U> {
+impl<T, U> From<Size2D<T, U>> for [T; 2] {
     #[inline]
-    fn into(self) -> [T; 2] {
-        [self.width, self.height]
+    fn from(s: Size2D<T, U>) -> Self {
+        [s.width, s.height]
     }
 }
 
@@ -701,10 +718,10 @@ impl<T, U> From<[T; 2]> for Size2D<T, U> {
     }
 }
 
-impl<T, U> Into<(T, T)> for Size2D<T, U> {
+impl<T, U> From<Size2D<T, U>> for (T, T) {
     #[inline]
-    fn into(self) -> (T, T) {
-        (self.width, self.height)
+    fn from(s: Size2D<T, U>) -> Self {
+        (s.width, s.height)
     }
 }
 
@@ -801,11 +818,10 @@ mod size2d {
             let sizes = [
                 Size2D::new(0.0, 1.0),
                 Size2D::new(1.0, 2.0),
-                Size2D::new(2.0, 3.0)
+                Size2D::new(2.0, 3.0),
             ];
             let sum = Size2D::new(3.0, 6.0);
             assert_eq!(sizes.iter().sum::<Size2D<_>>(), sum);
-            assert_eq!(sizes.into_iter().sum::<Size2D<_>>(), sum);
         }
 
         #[test]
@@ -990,6 +1006,35 @@ where
     }
 }
 
+#[cfg(feature = "arbitrary")]
+impl<'a, T, U> arbitrary::Arbitrary<'a> for Size3D<T, U>
+where
+    T: arbitrary::Arbitrary<'a>,
+{
+    fn arbitrary(u: &mut arbitrary::Unstructured<'a>) -> arbitrary::Result<Self> {
+        let (width, height, depth) = arbitrary::Arbitrary::arbitrary(u)?;
+        Ok(Size3D {
+            width,
+            height,
+            depth,
+            _unit: PhantomData,
+        })
+    }
+}
+
+#[cfg(feature = "bytemuck")]
+unsafe impl<T: Zeroable, U> Zeroable for Size3D<T, U> {}
+
+#[cfg(feature = "bytemuck")]
+unsafe impl<T: Pod, U: 'static> Pod for Size3D<T, U> {}
+
+#[cfg(feature = "malloc_size_of")]
+impl<T: MallocSizeOf, U> MallocSizeOf for Size3D<T, U> {
+    fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize {
+        self.width.size_of(ops) + self.height.size_of(ops) + self.depth.size_of(ops)
+    }
+}
+
 impl<T, U> Eq for Size3D<T, U> where T: Eq {}
 
 impl<T, U> PartialEq for Size3D<T, U>
@@ -1029,9 +1074,9 @@ impl<T: Default, U> Default for Size3D<T, U> {
 }
 
 impl<T, U> Size3D<T, U> {
-    /// The same as [`Zero::zero()`] but available without importing trait.
+    /// The same as [`Zero::zero`] but available without importing trait.
     ///
-    /// [`Zero::zero()`]: ./num/trait.Zero.html#tymethod.zero
+    /// [`Zero::zero`]: crate::num::Zero::zero
     pub fn zero() -> Self
     where
         T: Zero,
@@ -1282,7 +1327,7 @@ impl<T: NumCast + Copy, U> Size3D<T, U> {
 }
 
 impl<T: Float, U> Size3D<T, U> {
-    /// Returns true if all members are finite.
+    /// Returns `true` if all members are finite.
     #[inline]
     pub fn is_finite(self) -> bool {
         self.width.is_finite() && self.height.is_finite() && self.depth.is_finite()
@@ -1344,7 +1389,6 @@ impl<T: PartialOrd, U> Size3D<T, U> {
         self.width >= other.width && self.height >= other.height && self.depth >= other.depth
     }
 
-
     /// Returns vector with results of "greater than" operation on each component.
     pub fn greater_than(self, other: Self) -> BoolVector3D {
         BoolVector3D {
@@ -1369,7 +1413,7 @@ impl<T: PartialOrd, U> Size3D<T, U> {
         T: Zero,
     {
         let zero = T::zero();
-        !(self.width > zero && self.height > zero && self.depth <= zero)
+        !(self.width > zero && self.height > zero && self.depth > zero)
     }
 }
 
@@ -1394,7 +1438,7 @@ impl<T: PartialEq, U> Size3D<T, U> {
 }
 
 impl<T: Round, U> Round for Size3D<T, U> {
-    /// See [`Size3D::round()`](#method.round).
+    /// See [`Size3D::round`].
     #[inline]
     fn round(self) -> Self {
         self.round()
@@ -1402,7 +1446,7 @@ impl<T: Round, U> Round for Size3D<T, U> {
 }
 
 impl<T: Ceil, U> Ceil for Size3D<T, U> {
-    /// See [`Size3D::ceil()`](#method.ceil).
+    /// See [`Size3D::ceil`].
     #[inline]
     fn ceil(self) -> Self {
         self.ceil()
@@ -1410,7 +1454,7 @@ impl<T: Ceil, U> Ceil for Size3D<T, U> {
 }
 
 impl<T: Floor, U> Floor for Size3D<T, U> {
-    /// See [`Size3D::floor()`](#method.floor).
+    /// See [`Size3D::floor`].
     #[inline]
     fn floor(self) -> Self {
         self.floor()
@@ -1458,13 +1502,13 @@ impl<T: Copy + Add<T, Output = T>, U> Add<&Self> for Size3D<T, U> {
 }
 
 impl<T: Add<Output = T> + Zero, U> Sum for Size3D<T, U> {
-    fn sum<I: Iterator<Item=Self>>(iter: I) -> Self {
+    fn sum<I: Iterator<Item = Self>>(iter: I) -> Self {
         iter.fold(Self::zero(), Add::add)
     }
 }
 
 impl<'a, T: 'a + Add<Output = T> + Copy + Zero, U: 'a> Sum<&'a Self> for Size3D<T, U> {
-    fn sum<I: Iterator<Item=&'a Self>>(iter: I) -> Self {
+    fn sum<I: Iterator<Item = &'a Self>>(iter: I) -> Self {
         iter.fold(Self::zero(), Add::add)
     }
 }
@@ -1504,6 +1548,7 @@ impl<T: Copy + Mul, U> Mul<T> for Size3D<T, U> {
     type Output = Size3D<T::Output, U>;
 
     #[inline]
+    #[rustfmt::skip]
     fn mul(self, scale: T) -> Self::Output {
         Size3D::new(
             self.width * scale,
@@ -1546,6 +1591,7 @@ impl<T: Copy + Div, U> Div<T> for Size3D<T, U> {
     type Output = Size3D<T::Output, U>;
 
     #[inline]
+    #[rustfmt::skip]
     fn div(self, scale: T) -> Self::Output {
         Size3D::new(
             self.width / scale,
@@ -1592,13 +1638,13 @@ impl<T, U> From<mint::Vector3<T>> for Size3D<T, U> {
     }
 }
 #[cfg(feature = "mint")]
-impl<T, U> Into<mint::Vector3<T>> for Size3D<T, U> {
+impl<T, U> From<Size3D<T, U>> for mint::Vector3<T> {
     #[inline]
-    fn into(self) -> mint::Vector3<T> {
+    fn from(s: Size3D<T, U>) -> Self {
         mint::Vector3 {
-            x: self.width,
-            y: self.height,
-            z: self.depth,
+            x: s.width,
+            y: s.height,
+            z: s.depth,
         }
     }
 }
@@ -1610,10 +1656,10 @@ impl<T, U> From<Vector3D<T, U>> for Size3D<T, U> {
     }
 }
 
-impl<T, U> Into<[T; 3]> for Size3D<T, U> {
+impl<T, U> From<Size3D<T, U>> for [T; 3] {
     #[inline]
-    fn into(self) -> [T; 3] {
-        [self.width, self.height, self.depth]
+    fn from(s: Size3D<T, U>) -> Self {
+        [s.width, s.height, s.depth]
     }
 }
 
@@ -1624,10 +1670,10 @@ impl<T, U> From<[T; 3]> for Size3D<T, U> {
     }
 }
 
-impl<T, U> Into<(T, T, T)> for Size3D<T, U> {
+impl<T, U> From<Size3D<T, U>> for (T, T, T) {
     #[inline]
-    fn into(self) -> (T, T, T) {
-        (self.width, self.height, self.depth)
+    fn from(s: Size3D<T, U>) -> Self {
+        (s.width, s.height, s.depth)
     }
 }
 
@@ -1647,7 +1693,7 @@ pub const fn size3<T, U>(w: T, h: T, d: T) -> Size3D<T, U> {
 #[cfg(test)]
 mod size3d {
     mod ops {
-        use crate::default::Size3D;
+        use crate::default::{Size2D, Size3D};
         use crate::scale::Scale;
 
         pub enum Mm {}
@@ -1691,11 +1737,10 @@ mod size3d {
             let sizes = [
                 Size3D::new(0.0, 1.0, 2.0),
                 Size3D::new(1.0, 2.0, 3.0),
-                Size3D::new(2.0, 3.0, 4.0)
+                Size3D::new(2.0, 3.0, 4.0),
             ];
             let sum = Size3D::new(3.0, 6.0, 9.0);
             assert_eq!(sizes.iter().sum::<Size3D<_>>(), sum);
-            assert_eq!(sizes.into_iter().sum::<Size3D<_>>(), sum);
         }
 
         #[test]
@@ -1831,6 +1876,12 @@ mod size3d {
             assert_eq!(s1, Size3DMm::new(1.0, 2.0, 3.0));
         }
 
+        #[test]
+        fn test_nonempty() {
+            assert!(!Size2D::new(1.0, 1.0).is_empty());
+            assert!(!Size3D::new(1.0, 1.0, 1.0).is_empty());
+        }
+
         #[test]
         pub fn test_nan_empty() {
             use std::f32::NAN;
